@@ -1,8 +1,6 @@
+use strict; use warnings;
 package YAML::LibYAML;
-use 5.008003;
-use strict;
-use warnings;
-our $VERSION = '0.18';
+our $VERSION = '0.42';
 
 die "YAML::LibYAML has been renamed to YAML::XS. Please use YAML::XS instead.";
 
